@@ -289,7 +289,7 @@ read_child_stderr (GIOChannel *channel,
 {
   UDisksSpawnedJob *job = UDISKS_SPAWNED_JOB (user_data);
   gchar buf[1024];
-  gsize bytes_read = 0;
+  gsize bytes_read;
 
   g_io_channel_read_chars (channel, buf, sizeof buf, &bytes_read, NULL);
   g_string_append_len (job->child_stderr, buf, bytes_read);
@@ -303,7 +303,7 @@ read_child_stdout (GIOChannel *channel,
 {
   UDisksSpawnedJob *job = UDISKS_SPAWNED_JOB (user_data);
   gchar buf[1024];
-  gsize bytes_read = 0;
+  gsize bytes_read;
 
   g_io_channel_read_chars (channel, buf, sizeof buf, &bytes_read, NULL);
   g_string_append_len (job->child_stdout, buf, bytes_read);
@@ -316,7 +316,7 @@ write_child_stdin (GIOChannel *channel,
                    gpointer user_data)
 {
   UDisksSpawnedJob *job = UDISKS_SPAWNED_JOB (user_data);
-  gsize bytes_written = 0;
+  gsize bytes_written;
   gsize bytes_to_write = 0;
 
   if (job->input_string != NULL)
@@ -358,13 +358,11 @@ child_watch_cb (GPid     pid,
   gsize buf_size;
   gboolean ret;
 
-  buf_size = 0;
   if (g_io_channel_read_to_end (job->child_stdout_channel, &buf, &buf_size, NULL) == G_IO_STATUS_NORMAL)
     {
       g_string_append_len (job->child_stdout, buf, buf_size);
       g_free (buf);
     }
-  buf_size = 0;
   if (g_io_channel_read_to_end (job->child_stderr_channel, &buf, &buf_size, NULL) == G_IO_STATUS_NORMAL)
     {
       g_string_append_len (job->child_stderr, buf, buf_size);
@@ -796,21 +794,10 @@ udisks_spawned_job_release_resources (UDisksSpawnedJob *job)
        * GSource so we can nuke it once handled.
        */
       source = g_child_watch_source_new (job->child_pid);
-#if __GNUC__ >= 8
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wcast-function-type"
-#endif
-/* parameters of the callback depend on the source and can be different
- * from the required "generic" GSourceFunc, see:
- * https://developer.gnome.org/glib/stable/glib-The-Main-Event-Loop.html#g-source-set-callback
- */
       g_source_set_callback (source,
                              (GSourceFunc) child_watch_from_release_cb,
                              source,
                              (GDestroyNotify) g_source_destroy);
-#if __GNUC__ >= 8
-#pragma GCC diagnostic pop
-#endif
       g_source_attach (source, job->main_context);
       g_source_unref (source);
 
@@ -902,7 +889,7 @@ void udisks_spawned_job_start (UDisksSpawnedJob *job)
 {
   GError *error;
   gint child_argc;
-  gchar **child_argv = NULL;
+  gchar **child_argv;
   struct passwd pwstruct;
   gchar pwbuf[8192];
   struct passwd *pw = NULL;
@@ -990,18 +977,7 @@ void udisks_spawned_job_start (UDisksSpawnedJob *job)
     }
 
   job->child_watch_source = g_child_watch_source_new (job->child_pid);
-#if __GNUC__ >= 8
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wcast-function-type"
-#endif
-/* parameters of the callback depend on the source and can be different
- * from the required "generic" GSourceFunc, see:
- * https://developer.gnome.org/glib/stable/glib-The-Main-Event-Loop.html#g-source-set-callback
- */
   g_source_set_callback (job->child_watch_source, (GSourceFunc) child_watch_cb, job, NULL);
-#if __GNUC__ >= 8
-#pragma GCC diagnostic pop
-#endif
   g_source_attach (job->child_watch_source, job->main_context);
   g_source_unref (job->child_watch_source);
 
@@ -1011,68 +987,31 @@ void udisks_spawned_job_start (UDisksSpawnedJob *job)
         job->input_string_cursor = job->input_string->str;
 
       job->child_stdin_channel = g_io_channel_unix_new (job->child_stdin_fd);
-      /* we want to write binary, suppress checking the encoding: */
+      // we want to write binary, suppress checking the encoding:
       g_io_channel_set_encoding (job->child_stdin_channel, NULL, NULL);
       g_io_channel_set_flags (job->child_stdin_channel, G_IO_FLAG_NONBLOCK, NULL);
       job->child_stdin_source = g_io_create_watch (job->child_stdin_channel, G_IO_OUT);
-#if __GNUC__ >= 8
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wcast-function-type"
-#endif
-/* parameters of the callback depend on the source and can be different
- * from the required "generic" GSourceFunc, see:
- * https://developer.gnome.org/glib/stable/glib-The-Main-Event-Loop.html#g-source-set-callback
- */
       g_source_set_callback (job->child_stdin_source, (GSourceFunc) write_child_stdin, job, NULL);
-#if __GNUC__ >= 8
-#pragma GCC diagnostic pop
-#endif
       g_source_attach (job->child_stdin_source, job->main_context);
       g_source_unref (job->child_stdin_source);
     }
 
   job->child_stdout_channel = g_io_channel_unix_new (job->child_stdout_fd);
-  /* we want to read binary, suppress checking the encoding: */
-  g_io_channel_set_encoding (job->child_stdout_channel, NULL, NULL);
   g_io_channel_set_flags (job->child_stdout_channel, G_IO_FLAG_NONBLOCK, NULL);
   job->child_stdout_source = g_io_create_watch (job->child_stdout_channel, G_IO_IN);
-#if __GNUC__ >= 8
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wcast-function-type"
-#endif
-/* parameters of the callback depend on the source and can be different
- * from the required "generic" GSourceFunc, see:
- * https://developer.gnome.org/glib/stable/glib-The-Main-Event-Loop.html#g-source-set-callback
- */
   g_source_set_callback (job->child_stdout_source, (GSourceFunc) read_child_stdout, job, NULL);
-#if __GNUC__ >= 8
-#pragma GCC diagnostic pop
-#endif
   g_source_attach (job->child_stdout_source, job->main_context);
   g_source_unref (job->child_stdout_source);
 
   job->child_stderr_channel = g_io_channel_unix_new (job->child_stderr_fd);
-  /* we want to read binary, suppress checking the encoding: */
-  g_io_channel_set_encoding (job->child_stderr_channel, NULL, NULL);
   g_io_channel_set_flags (job->child_stderr_channel, G_IO_FLAG_NONBLOCK, NULL);
   job->child_stderr_source = g_io_create_watch (job->child_stderr_channel, G_IO_IN);
-#if __GNUC__ >= 8
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wcast-function-type"
-#endif
-/* parameters of the callback depend on the source and can be different
- * from the required "generic" GSourceFunc, see:
- * https://developer.gnome.org/glib/stable/glib-The-Main-Event-Loop.html#g-source-set-callback
- */
   g_source_set_callback (job->child_stderr_source, (GSourceFunc) read_child_stderr, job, NULL);
-#if __GNUC__ >= 8
-#pragma GCC diagnostic pop
-#endif
   g_source_attach (job->child_stderr_source, job->main_context);
   g_source_unref (job->child_stderr_source);
 
  out:
-  g_strfreev (child_argv);
+  ;
 }
 
 /* manage strings with potentially unsafe content */
